r70877 - in /trunk/libparse-exuberantctags-perl: Changes ExuberantCTags.xs META.yml Makefile.PL README debian/changelog lib/Parse/ExuberantCTags.pm

jawnsy-guest at users.alioth.debian.org jawnsy-guest at users.alioth.debian.org
Tue Mar 8 12:12:37 UTC 2011


Author: jawnsy-guest
Date: Tue Mar  8 12:10:37 2011
New Revision: 70877

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=70877
Log:
Changes to build system, no feature changes
IGNORE-VERSION: 1.02-1
* New upstream release

Modified:
    trunk/libparse-exuberantctags-perl/Changes
    trunk/libparse-exuberantctags-perl/ExuberantCTags.xs
    trunk/libparse-exuberantctags-perl/META.yml
    trunk/libparse-exuberantctags-perl/Makefile.PL
    trunk/libparse-exuberantctags-perl/README
    trunk/libparse-exuberantctags-perl/debian/changelog
    trunk/libparse-exuberantctags-perl/lib/Parse/ExuberantCTags.pm

Modified: trunk/libparse-exuberantctags-perl/Changes
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/Changes?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/Changes (original)
+++ trunk/libparse-exuberantctags-perl/Changes Tue Mar  8 12:10:37 2011
@@ -1,4 +1,8 @@
 Revision history for Perl extension Parse::ExuberantCTags.
+
+1.02  Tue Sep 21 22:23 2010
+  - Fix compilation in C89 mode (RT #61526)
+  - Better Makefile.PL (Alexandr Ciornii)
 
 1.01  Tue Jun 30 16:25 2009
   - band-aid fix for perls older than 5.10 (include ppport.h in extra cc file)

Modified: trunk/libparse-exuberantctags-perl/ExuberantCTags.xs
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/ExuberantCTags.xs?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/ExuberantCTags.xs (original)
+++ trunk/libparse-exuberantctags-perl/ExuberantCTags.xs Tue Mar  8 12:10:37 2011
@@ -28,7 +28,7 @@
 new(CLASS, path)
     char* CLASS
     char* path
-  INIT:
+  PREINIT:
     tagFile* theFile;
     tagFileInfo* theInfo;
   CODE:
@@ -76,9 +76,8 @@
 DESTROY(self)
     myTagFile* self
   CODE:
-    if (self->file != NULL) {
+    if (self->file != NULL)
       tagsClose(self->file);
-    }
     safefree(self->fileInfo);
     safefree(self->entryBuffer);
     safefree(self);
@@ -87,7 +86,7 @@
 SV*
 firstTag(self)
     myTagFile* self
-  INIT:
+  PREINIT:
     HV* result;
   CODE:
     if (self->file == NULL)
@@ -103,7 +102,7 @@
 SV*
 nextTag(self)
     myTagFile* self
-  INIT:
+  PREINIT:
     HV* result;
   CODE:
     if (self->file == NULL)
@@ -120,7 +119,7 @@
 findTag(self, name, ...)
     myTagFile* self
     char* name
-  INIT:
+  PREINIT:
     int options = TAG_FULLMATCH | TAG_OBSERVECASE;
     unsigned int i;
     SV* sv;
@@ -155,7 +154,7 @@
 SV*
 findNextTag(self)
     myTagFile* self
-  INIT:
+  PREINIT:
     HV* result;
   CODE:
     if (self->file == NULL)

Modified: trunk/libparse-exuberantctags-perl/META.yml
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/META.yml?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/META.yml (original)
+++ trunk/libparse-exuberantctags-perl/META.yml Tue Mar  8 12:10:37 2011
@@ -1,21 +1,26 @@
 --- #YAML:1.0
 name:               Parse-ExuberantCTags
-version:            1.01
+version:            1.02
 abstract:           Efficiently parse exuberant ctags files
 author:
     - Steffen Mueller <smueller at cpan.org>
-license:            unknown
+license:            perl
 distribution_type:  module
 configure_requires:
     ExtUtils::MakeMaker:  0
 build_requires:
-    ExtUtils::MakeMaker:  0
-requires:  {}
+    Data::Dumper:  0
+    File::Spec:    0
+    Test::More:    0
+requires:
+    perl:  5.006001
+resources:
+    repository:  http://svn.ali.as/cpan/trunk/Parse-ExuberantCTags
 no_index:
     directory:
         - t
         - inc
-generated_by:       ExtUtils::MakeMaker version 6.50
+generated_by:       ExtUtils::MakeMaker version 6.56
 meta-spec:
     url:      http://module-build.sourceforge.net/META-spec-v1.4.html
     version:  1.4

Modified: trunk/libparse-exuberantctags-perl/Makefile.PL
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/Makefile.PL?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/README (original)
+++ trunk/libparse-exuberantctags-perl/README Tue Mar  8 12:10:37 2011
@@ -4,16 +4,16 @@
 SYNOPSIS
       use Parse::ExuberantCTags;
       my $parser = Parse::ExuberantCTags->new( 'tags_filename' );
-      
-  # find a given tag that starts with 'foo' and do not ignore case
+  
+      # find a given tag that starts with 'foo' and do not ignore case
       my $tag = $parser->findTag("foo", ignore_case => 0, partial => 1);
       if (defined $tag) {
         print $tag->{name}, "\n";
       }
       $tag = $parser->findNextTag();
       # ...
-      
-  # iterator interface (use findTag instead, it does a binary search)
+  
+      # iterator interface (use findTag instead, it does a binary search)
       $tag = $parser->firstTag;
       while (defined($tag = $parser->nextTag)) {
         # use the tag structure

Modified: trunk/libparse-exuberantctags-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/debian/changelog?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/debian/changelog (original)
+++ trunk/libparse-exuberantctags-perl/debian/changelog Tue Mar  8 12:10:37 2011
@@ -1,4 +1,7 @@
-libparse-exuberantctags-perl (1.01-2) UNRELEASED; urgency=low
+libparse-exuberantctags-perl (1.02-1) UNRELEASED; urgency=low
+
+  Changes to build system, no feature changes
+  IGNORE-VERSION: 1.02-1
 
   [ Salvatore Bonaccorso ]
   * debian/control: Changed: Replace versioned (build-)dependency on
@@ -8,7 +11,10 @@
   [ Ryan Niebur ]
   * Update ryan52's email address
 
- -- Ryan Niebur <ryan at debian.org>  Fri, 25 Sep 2009 00:25:55 -0700
+  [ Jonathan Yu ]
+  * New upstream release
+
+ -- Jonathan Yu <jawnsy at cpan.org>  Mon, 07 Mar 2011 22:57:20 -0500
 
 libparse-exuberantctags-perl (1.01-1) unstable; urgency=low
 

Modified: trunk/libparse-exuberantctags-perl/lib/Parse/ExuberantCTags.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/lib/Parse/ExuberantCTags.pm?rev=70877&op=diff
==============================================================================
--- trunk/libparse-exuberantctags-perl/lib/Parse/ExuberantCTags.pm (original)
+++ trunk/libparse-exuberantctags-perl/lib/Parse/ExuberantCTags.pm Tue Mar  8 12:10:37 2011
@@ -4,7 +4,7 @@
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 require XSLoader;
 XSLoader::load('Parse::ExuberantCTags', $VERSION);
@@ -155,7 +155,7 @@
 
 The XS wrapper and this document are:
 
-Copyright (C) 2009 by Steffen Mueller
+Copyright (C) 2009-2010 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.6 or,




More information about the Pkg-perl-cvs-commits mailing list
--- trunk/libparse-exuberantctags-perl/Makefile.PL (original)
+++ trunk/libparse-exuberantctags-perl/Makefile.PL Tue Mar  8 12:10:37 2011
@@ -1,16 +1,52 @@
-use 5.006001;
-use ExtUtils::MakeMaker;
-# See lib/ExtUtils/MakeMaker.pm for details of how to influence
-# the contents of the Makefile that is written.
-WriteMakefile(
-    NAME              => 'Parse::ExuberantCTags',
-    VERSION_FROM      => 'lib/Parse/ExuberantCTags.pm', # finds $VERSION
-    PREREQ_PM         => {}, # e.g., Module::Name => 1.1
-    ABSTRACT_FROM     => 'lib/Parse/ExuberantCTags.pm', # retrieve abstract from module
-    AUTHOR            => 'Steffen Mueller <smueller at cpan.org>',
-    LIBS              => [''], # e.g., '-lm'
-    DEFINE            => '', # e.g., '-DHAVE_SOMETHING'
-    INC               => '-I.', # e.g., '-I. -I/usr/include/other'
-    OBJECT            => '$(O_FILES)', # link all the C files too
-    'TYPEMAPS'        => ['perlobject.map', 'typemap'],
-);
+use 5.006001;
+use ExtUtils::MakeMaker;
+# See lib/ExtUtils/MakeMaker.pm for details of how to influence
+# the contents of the Makefile that is written.
+WriteMakefile1(
+    NAME              => 'Parse::ExuberantCTags',
+    VERSION_FROM      => 'lib/Parse/ExuberantCTags.pm', # finds $VERSION
+    PREREQ_PM         => {}, # e.g., Module::Name => 1.1
+    ABSTRACT_FROM     => 'lib/Parse/ExuberantCTags.pm', # retrieve abstract from module
+    AUTHOR            => 'Steffen Mueller <smueller at cpan.org>',
+    LIBS              => [''], # e.g., '-lm'
+    DEFINE            => '', # e.g., '-DHAVE_SOMETHING'
+    INC               => '-I.', # e.g., '-I. -I/usr/include/other'
+    OBJECT            => '$(O_FILES)', # link all the C files too
+    'TYPEMAPS'        => ['perlobject.map', 'typemap'],
+    LICENSE           => 'perl',
+    MIN_PERL_VERSION  => '5.006001',
+    META_MERGE        => {
+        resources => {
+            repository => 'http://svn.ali.as/cpan/trunk/Parse-ExuberantCTags',
+        },
+    },
+    BUILD_REQUIRES => {
+        'Test::More' => 0,
+        'Data::Dumper' => 0,
+        'File::Spec' => 0,
+    },
+);
+
+sub WriteMakefile1 {  #Written by Alexandr Ciornii, version 0.21. Added by eumm-upgrade.
+    my %params=@_;
+    my $eumm_version=$ExtUtils::MakeMaker::VERSION;
+    $eumm_version=eval $eumm_version;
+    die "EXTRA_META is deprecated" if exists $params{EXTRA_META};
+    die "License not specified" if not exists $params{LICENSE};
+    if ($params{BUILD_REQUIRES} and $eumm_version < 6.5503) {
+        #EUMM 6.5502 has problems with BUILD_REQUIRES
+        $params{PREREQ_PM}={ %{$params{PREREQ_PM} || {}} , %{$params{BUILD_REQUIRES}} };
+        delete $params{BUILD_REQUIRES};
+    }
+    delete $params{CONFIGURE_REQUIRES} if $eumm_version < 6.52;
+    delete $params{MIN_PERL_VERSION} if $eumm_version < 6.48;
+    delete $params{META_MERGE} if $eumm_version < 6.46;
+    delete $params{META_ADD} if $eumm_version < 6.46;
+    delete $params{LICENSE} if $eumm_version < 6.31;
+    delete $params{AUTHOR} if $] < 5.005;
+    delete $params{ABSTRACT_FROM} if $] < 5.005;
+    delete $params{BINARY_LOCATION} if $] < 5.005;
+
+    WriteMakefile(%params);
+}
+

Modified: trunk/libparse-exuberantctags-perl/README
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libparse-exuberantctags-perl/README?rev=70877&op=diff
==============================================================================